package net.peachjean.slf4j.mojo;

import org.apache.maven.plugin.logging.Log;
import org.slf4j.Logger;
import org.slf4j.Marker;
import org.slf4j.helpers.MarkerIgnoringBase;
import org.slf4j.helpers.MessageFormatter;

class MojoLoggerAdapter extends MarkerIgnoringBase
{
	private final String loggerName;

	public MojoLoggerAdapter(final String loggerName)
	{
		this.loggerName = loggerName;
	}

	@Override
	public String getName()
	{
		return this.loggerName;
	}

	private Log log() {
		return CurrentMojoLogger.getCurrentMavenLog();
	}

	@Override
	public boolean isTraceEnabled()
	{
		return log().isDebugEnabled();
	}

	@Override
	public void trace(final String s)
	{
		log().debug(s);
	}

	@Override
	public void trace(final String format, final Object arg)
	{
		if(log().isDebugEnabled()) {
			log().debug(MessageFormatter.format(format, arg).getMessage());
		}
	}

	@Override
	public void trace(final String format, final Object arg1, final Object arg2)
	{
		if(log().isDebugEnabled()) {
			log().debug(MessageFormatter.format(format, arg1, arg2).getMessage());
		}
	}

	@Override
	public void trace(final String format, final Object[] argArray)
	{
		if(log().isDebugEnabled()) {
			log().debug(MessageFormatter.arrayFormat(format, argArray).getMessage());
		}
	}

	@Override
	public void trace(final String msg, final Throwable t)
	{
		log().debug(msg, t);
	}

	@Override
	public boolean isDebugEnabled()
	{
		return log().isDebugEnabled();
	}

	@Override
	public void debug(final String msg)
	{
		log().debug(msg);
	}

	@Override
	public void debug(final String format, final Object arg)
	{
		if(log().isDebugEnabled()) {
			log().debug(MessageFormatter.format(format, arg).getMessage());
		}
	}

	@Override
	public void debug(final String format, final Object arg1, final Object arg2)
	{
		if(log().isDebugEnabled()) {
			log().debug(MessageFormatter.format(format, arg1, arg2).getMessage());
		}
	}

	@Override
	public void debug(final String format, final Object[] argArray)
	{
		if(log().isDebugEnabled()) {
			log().debug(MessageFormatter.arrayFormat(format, argArray).getMessage());
		}

	}

	@Override
	public void debug(final String msg, final Throwable t)
	{
		log().debug(msg, t);
	}

	@Override
	public boolean isInfoEnabled()
	{
		return log().isInfoEnabled();
	}

	@Override
	public void info(final String msg)
	{
		log().info(msg);
	}

	@Override
	public void info(final String format, final Object arg)
	{
		if(log().isInfoEnabled()) {
			log().info(MessageFormatter.format(format, arg).getMessage());
		}
	}

	@Override
	public void info(final String format, final Object arg1, final Object arg2)
	{
		if(log().isInfoEnabled()) {
			log().info(MessageFormatter.format(format, arg1, arg2).getMessage());
		}
	}

	@Override
	public void info(final String format, final Object[] argArray)
	{
		if(log().isInfoEnabled()) {
			log().info(MessageFormatter.arrayFormat(format, argArray).getMessage());
		}
	}

	@Override
	public void info(final String msg, final Throwable t)
	{
		log().info(msg, t);
	}

	@Override
	public boolean isWarnEnabled()
	{
		return log().isWarnEnabled();
	}

	@Override
	public void warn(final String msg)
	{
		log().warn(msg);
	}

	@Override
	public void warn(final String format, final Object arg)
	{
		if(log().isWarnEnabled()) {
			log().warn(MessageFormatter.format(format, arg).getMessage());
		}
	}

	@Override
	public void warn(final String format, final Object[] argArray)
	{
		if(log().isWarnEnabled()) {
			log().warn(MessageFormatter.arrayFormat(format, argArray).getMessage());
		}
	}

	@Override
	public void warn(final String format, final Object arg1, final Object arg2)
	{
		if(log().isWarnEnabled()) {
			log().warn(MessageFormatter.format(format, arg1, arg2).getMessage());
		}
	}

	@Override
	public void warn(final String msg, final Throwable t)
	{
		log().warn(msg, t);
	}

	@Override
	public boolean isErrorEnabled()
	{
		return log().isErrorEnabled();
	}

	@Override
	public void error(final String msg)
	{
		log().error(msg);
	}

	@Override
	public void error(final String format, final Object arg)
	{
		if(log().isErrorEnabled()) {
			log().error(MessageFormatter.format(format, arg).getMessage());
		}
	}

	@Override
	public void error(final String format, final Object arg1, final Object arg2)
	{
		if(log().isErrorEnabled()) {
			log().error(MessageFormatter.format(format, arg1, arg2).getMessage());
		}
	}

	@Override
	public void error(final String format, final Object[] argArray)
	{
		if(log().isErrorEnabled()) {
			log().error(MessageFormatter.arrayFormat(format, argArray).getMessage());
		}
	}

	@Override
	public void error(final String msg, final Throwable t)
	{
		log().error(msg, t);
	}
}
